PlayerInput

Struct PlayerInput 

pub struct PlayerInput {
    forward: bool,
    backward: bool,
    left: bool,
    right: bool,
    jump: bool,
    shift: bool,
    sprint: bool,
}
Vanilla Input snapshot from the latest serverbound player-input packet.

Fields

forward: boolbackward: boolleft: boolright: booljump: boolshift: boolsprint: bool

Implementations

Source

impl PlayerInput

pub const EMPTY: Self

Empty input state used before the client sends input.

pub const fn from_flags(flags: u8) -> Self

Decodes vanilla Input bit flags.

pub const fn flags(self) -> u8

Encodes this input snapshot as vanilla Input bit flags.

pub const fn forward(self) -> bool

Returns true if forward input is pressed.

pub const fn backward(self) -> bool

Returns true if backward input is pressed.

pub const fn left(self) -> bool

Returns true if left input is pressed.

pub const fn right(self) -> bool

Returns true if right input is pressed.

pub const fn jump(self) -> bool

Returns true if jump input is pressed.

pub const fn shift(self) -> bool

Returns true if shift input is pressed.

pub const fn sprint(self) -> bool

Returns true if sprint input is pressed.

pub const fn left_intent(self) -> f32

Returns vanilla’s unrotated left/right movement intent.

pub const fn forward_intent(self) -> f32

Returns vanilla’s unrotated forward/backward movement intent.

pub fn movement_input(self) -> DVec3

Returns the unrotated movement input vector used by vanilla player intent.